##################################
FitBenchmarking User Documentation
##################################

In these pages we describe how to install, run, and set options to use
the FitBenchmarking software.

.. toctree::
    :titlesonly:
    :maxdepth: 2
    :caption: Contents:

    install_instructions/index
    running
    output/index
    BenchmarkProblems
    options/index
    problem_definition_files/index
    tests
    notes

